
<!--
FrozenIsBool False
-->

A connecter can do a mapConnect in a team that has the same prefix str.
Note that the get of the To Variable is with the path of the top connecter that call the mapConnect.